import { useState, useEffect } from "react";
import { motion } from "framer-motion";
import { Crown, UserCheck, Sparkles, LogIn, User, LogOut, Coins, ChevronDown, Mail, AlertCircle } from "lucide-react";
import { Button } from "@/components/ui/button";
import { DropdownMenu, DropdownMenuContent, DropdownMenuItem, DropdownMenuTrigger } from "@/components/ui/dropdown-menu";
import { ThemeToggle } from "@/components/theme-toggle";
import PersonaForm from "@/components/persona-form";
import PersonaResult from "@/components/persona-result";

import PaywallModal from "@/components/paywall-modal";
import AuthModal from "@/components/auth-modal";
import { useQuery } from "@tanstack/react-query";
import { Persona } from "@shared/schema";
import { useLocation, Link, useNavigate } from "react-router-dom";
import { useToast } from "@/hooks/use-toast";
import { useAuth } from "@/hooks/useAuth";
import { signOut } from "firebase/auth";
import { auth } from "@/lib/firebase";

export default function Home() {
  const [generatedPersona, setGeneratedPersona] = useState<Persona | null>(null);
  const [showPaywall, setShowPaywall] = useState(false);
  const [showAuthModal, setShowAuthModal] = useState(false);
  const [isGenerating, setIsGenerating] = useState(false);
  const navigate = useNavigate();
  const { toast } = useToast();
  const { user, firebaseUser, tokenBalance } = useAuth();

  // SEO: Set page title and meta description
  useEffect(() => {
    document.title = "ForgePersona - AI User Persona Generator | Create Detailed Customer Profiles Instantly";
    const metaDescription = document.querySelector('meta[name="description"]');
    if (metaDescription) {
      metaDescription.setAttribute('content', 'Generate detailed user personas in seconds with AI. Perfect for marketers, UX designers, and product teams. Create accurate customer profiles, analyze target audiences, and improve your marketing strategy with our advanced persona generation tool.');
    }
    
    // Ensure canonical URL is set for homepage
    const canonicalLink = document.querySelector('link[rel="canonical"]');
    if (canonicalLink) {
      canonicalLink.setAttribute('href', 'https://personaforge.com/');
    }
  }, []);

  // Check for successful payment
  useEffect(() => {
    const urlParams = new URLSearchParams(window.location.search);
    if (urlParams.get('success') === 'true') {
      toast({
        title: "Welcome to PersonaForge Pro!",
        description: "Your subscription is now active. You have unlimited persona generation.",
      });
      // Clean up the URL
      window.history.replaceState({}, document.title, window.location.pathname);
    }
  }, [toast]);

  const { data: personaCountData } = useQuery({
    queryKey: ["/api/persona-count"],
    refetchInterval: 300000, // Only refetch every 5 minutes for better performance
    staleTime: 240000, // Consider data fresh for 4 minutes
    retry: 1, // Reduce retry attempts for better performance
    refetchOnWindowFocus: false, // Don't refetch on window focus for better performance
    enabled: true, // Always enabled for better performance
  });

  const personaCount = (personaCountData as { count: number })?.count || 0;
  const hasExceededLimit = !user; // Only require authentication, not token check here

  const handlePersonaGenerated = (persona: Persona) => {
    setGeneratedPersona(persona);
    setIsGenerating(false);
  };

  const handleGenerateAttempt = () => {
    if (!firebaseUser) {
      setShowAuthModal(true);
    } else if (tokenBalance <= 0) {
      setShowPaywall(true);
    } else {
      setIsGenerating(true);
    }
  };

  const handleUpgradeClick = () => {
    navigate("/upgrade");
  };

  const handleSignOut = async () => {
    try {
      await signOut(auth);
      toast({
        title: "Signed out successfully",
        description: "You have been signed out of your account.",
      });
    } catch (error: any) {
      toast({
        title: "Sign out failed",
        description: error.message || "There was an error signing out.",
        variant: "destructive",
      });
    }
  };

  return (
    <div className="min-h-screen bg-background dark:bg-background mesh-bg">
      {/* Header */}
      <motion.header 
        className="bg-card/80 dark:bg-card/80 backdrop-blur-md shadow-sm border-b border-border/50"
        initial={{ opacity: 0, y: -20 }}
        animate={{ opacity: 1, y: 0 }}
        transition={{ duration: 0.5 }}
        role="banner"
      >
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex justify-between items-center py-4 sm:py-6">
            <div className="flex items-center space-x-2 sm:space-x-4">
              <motion.div 
                className="w-10 h-10 sm:w-12 sm:h-12 gradient-bg rounded-xl flex items-center justify-center shadow-lg"
                whileHover={{ scale: 1.05 }}
                whileTap={{ scale: 0.95 }}
                role="img"
                aria-label="ForgePersona Logo"
              >
                <UserCheck className="text-white h-5 w-5 sm:h-6 sm:w-6" />
              </motion.div>
              <div className="min-w-0">
                <h1 className="text-lg sm:text-2xl font-bold text-foreground">ForgePersona</h1>
                <p className="text-xs sm:text-sm text-muted-foreground hidden sm:block" role="doc-subtitle">AI-Powered Persona Generator</p>
              </div>
            </div>
            <div className="flex items-center space-x-1 sm:space-x-3">
              <ThemeToggle />
              
              {firebaseUser ? (
                <div className="flex items-center space-x-3 sm:space-x-4">
                  {/* Token Balance Badge */}
                  <div className="flex items-center space-x-2 px-3 py-1.5 bg-orange-50 dark:bg-orange-900/20 rounded-full border border-orange-200 dark:border-orange-800">
                    <Coins className="h-4 w-4 text-orange-600 dark:text-orange-400" />
                    <span className="text-sm font-medium text-orange-800 dark:text-orange-200">
                      {tokenBalance} token{tokenBalance !== 1 ? 's' : ''}
                    </span>
                  </div>
                  
                  {/* Buy Tokens Button */}
                  <motion.div
                    whileHover={{ scale: 1.05 }}
                    whileTap={{ scale: 0.95 }}
                  >
                    <Button 
                      onClick={handleUpgradeClick}
                      size="sm"
                      className="gradient-bg text-white hover:opacity-90"
                      aria-label="Buy more tokens"
                    >
                      <Coins className="h-4 w-4 sm:mr-2" />
                      <span className="hidden sm:inline">Buy Tokens</span>
                    </Button>
                  </motion.div>
                  
                  {/* User Menu Dropdown */}
                  <DropdownMenu>
                    <DropdownMenuTrigger asChild>
                      <motion.div
                        whileHover={{ scale: 1.05 }}
                        whileTap={{ scale: 0.95 }}
                      >
                        <Button 
                          variant="outline"
                          size="sm"
                          className="border-muted-foreground/20 text-muted-foreground hover:bg-muted hover:text-primary transition-colors"
                        >
                          <User className="h-4 w-4 sm:mr-2" />
                          <span className="hidden sm:inline">Account</span>
                          <ChevronDown className="h-3 w-3 ml-1" />
                        </Button>
                      </motion.div>
                    </DropdownMenuTrigger>
                    <DropdownMenuContent align="end" className="w-48">
                      <DropdownMenuItem disabled className="text-xs text-muted-foreground">
                        {firebaseUser.email}
                      </DropdownMenuItem>
                      <DropdownMenuItem onClick={handleSignOut} className="text-sm hover:text-primary transition-colors">
                        <LogOut className="h-4 w-4 mr-2" />
                        Sign Out
                      </DropdownMenuItem>
                    </DropdownMenuContent>
                  </DropdownMenu>
                </div>
              ) : (
                <div className="flex items-center space-x-3">
                  <motion.div
                    whileHover={{ scale: 1.05 }}
                    whileTap={{ scale: 0.95 }}
                  >
                    <Button 
                      onClick={() => navigate("/signin")}
                      variant="outline"
                      size="sm"
                      className="border-primary text-primary hover:bg-primary hover:text-white transition-colors"
                    >
                      <LogIn className="h-4 w-4 sm:mr-2" />
                      <span className="hidden sm:inline">Sign In</span>
                    </Button>
                  </motion.div>
                  <motion.div
                    whileHover={{ scale: 1.05 }}
                    whileTap={{ scale: 0.95 }}
                  >
                    <Button 
                      onClick={handleUpgradeClick}
                      size="sm"
                      className="gradient-bg text-white hover:opacity-90 shadow-lg transition-all"
                    >
                      <Crown className="h-4 w-4 sm:mr-2" />
                      <span className="hidden sm:inline">Upgrade</span>
                    </Button>
                  </motion.div>
                </div>
              )}
            </div>
          </div>
        </div>
      </motion.header>

      {/* Early Access Banner */}
      <motion.div
        className="bg-gradient-to-r from-amber-50 to-orange-50 dark:from-amber-900/20 dark:to-orange-900/20 border-b border-amber-200 dark:border-amber-800"
        initial={{ opacity: 0, y: -10 }}
        animate={{ opacity: 1, y: 0 }}
        transition={{ duration: 0.5, delay: 0.1 }}
      >
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-3">
          <div className="flex items-center justify-center space-x-3 text-sm">
            <AlertCircle className="h-4 w-4 text-amber-600 dark:text-amber-400 flex-shrink-0" />
            <p className="text-amber-800 dark:text-amber-200 text-center">
              <span className="font-medium">You're using the early access version of PersonaForge</span>
              <span className="mx-2">—</span>
              <span>things may shift quickly! Your feedback helps shape what's next.</span>
            </p>
            <a 
              href="mailto:k.shahan786@gmail.com"
              className="inline-flex items-center space-x-1 text-amber-700 dark:text-amber-300 hover:text-amber-900 dark:hover:text-amber-100 transition-colors underline decoration-dotted underline-offset-2"
            >
              <Mail className="h-3 w-3" />
              <span>Contact</span>
            </a>
          </div>
        </div>
      </motion.div>

      {/* Main Content */}
      <main className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-4 sm:py-8" role="main">
        <motion.div 
          className="grid grid-cols-1 xl:grid-cols-2 gap-4 sm:gap-6 lg:gap-8"
          initial={{ opacity: 0, y: 20 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.6, delay: 0.2 }}
        >
          {/* Left Column - Form */}
          <div className="space-y-4 sm:space-y-6 order-1 xl:order-1" role="form" aria-labelledby="persona-form-title">
            <PersonaForm 
              onGenerate={handleGenerateAttempt}
              onPersonaGenerated={handlePersonaGenerated}
              isGenerating={isGenerating}
              hasExceededLimit={hasExceededLimit}
            />
          </div>

          {/* Right Column - Results */}
          <div className="space-y-4 sm:space-y-6 order-2 xl:order-2" role="region" aria-label="Generated persona results">
            <PersonaResult 
              persona={generatedPersona}
              isGenerating={isGenerating}
            />
          </div>
        </motion.div>
      </main>

      {/* Footer */}
      <motion.footer 
        className="bg-background border-t border-border mt-16"
        initial={{ opacity: 0 }}
        animate={{ opacity: 1 }}
        transition={{ duration: 0.5, delay: 0.4 }}
        role="contentinfo"
      >
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
          <div className="text-center space-y-4">
            <p className="text-muted-foreground">
              <Sparkles className="inline h-4 w-4 text-primary mr-2" />
              Powered by AI • Built for designers, marketers, and product teams
            </p>
            <div className="flex justify-center items-center space-x-6 text-sm">
              <Link to="/privacy" className="text-muted-foreground hover:text-primary transition-colors">
                Privacy Policy
              </Link>
              <span className="text-muted-foreground/50">•</span>
              <Link to="/terms" className="text-muted-foreground hover:text-primary transition-colors">
                Terms of Service
              </Link>
            </div>
            <p className="text-xs text-muted-foreground">
              ForgePersona is an independent tool hosted at personaforge.com — not affiliated with any previous brand.
            </p>
          </div>
        </div>
      </motion.footer>

      {/* Paywall Modal */}
      <PaywallModal 
        isOpen={showPaywall} 
        onClose={() => setShowPaywall(false)} 
      />
      
      {/* Auth Modal */}
      <AuthModal 
        isOpen={showAuthModal} 
        onClose={() => setShowAuthModal(false)} 
      />
    </div>
  );
}
